<?php

/**
 * A response object to handle and parse Pin payments.
 */
class CommercePinResponse {

  // The raw response object.
  protected $response = FALSE;

  /**
   * Construct the object with the API response.
   *
   * @param $api_response
   *   The response object returned from the payment gateway.
   */
  function __construct($api_response) {
    $this->response = $api_response;
  }

  /**
   * @return Boolean
   *   If our transaction was successful.
   */
  function wasSuccessful() {
    return
      isset($this->response->response->success)
      && $this->response->response->success == TRUE;
  }

  /**
   * @return String
   *   The unique token that represents our transaction.
   */
  function getToken() {
    return $this->response->response->token;
  }

  /**
   * @return String
   *   A correctly formatted, human readable error message.
   */
  function getErrorMessage() {

    // There is no error message for successful transactions.
    if ($this->wasSuccessful()) {
      return '';
    }

    // Collect all the errors from the response.
    $error_message = array($this->response->error_description);
    foreach ($this->response->messages as $response_message) {
      if (isset($response_message->message)) {
        $error_message[] = $response_message->message;
      }
    }

    return implode("\n", $error_message);
  }

  /**
   * @return Object
   *   The raw response object.
   */
  function getRawResponse() {
    return $this->response;
  }
}
